@@ -138,6 +138,8 @@ void BranchObj::clear()
 
 	while (!branch.isEmpty())
 		delete branch.takeFirst();
+
+	if (scrolled) unScroll();	
 }
 
 bool isAbove (BranchObj* a, BranchObj *b)
@@ -351,17 +353,18 @@ void BranchObj::setVisibility(bool v, int toDepth)
 		standardFlags->setVisibility(v);
 		LinkableMapObj::setVisibility (v);
 		
+		int i;
+		for (i=0; i<floatimage.size(); ++i)
+			floatimage.at(i)->setVisibility (v);
+		for (i=0; i<xlink.size(); ++i)	
+			xlink.at(i)->setVisibility ();	
+
 		// Only change childs, if I am not scrolled
 		if (!scrolled && (depth < toDepth))
 		{
 			// Now go recursivly through all childs
-			int i;
 			for (i=0; i<branch.size(); ++i)
 				branch.at(i)->setVisibility (v,toDepth);	
-			for (i=0; i<floatimage.size(); ++i)
-				floatimage.at(i)->setVisibility (v);
-			for (i=0; i<xlink.size(); ++i)	
-				xlink.at(i)->setVisibility ();	
 		}
     } // depth <= toDepth	
 	requestReposition();
@@ -1047,7 +1050,7 @@ BranchObj* BranchObj::addBranch()
     branch.append (newbo);
     newbo->setParObj(this);
 	newbo->setDefAttr(NewBranch);
-    newbo->setHeading ("new");
+    //newbo->setHeading ("new");
 	if (scrolled)
 		newbo->setVisibility (false);
 	else	
@@ -1304,7 +1307,6 @@ BranchObj* BranchObj::linkTo (BranchObj* dst, int pos)
 			bo->setDefAttr(MovedBranch);
 			updateLink();
 			return bo;
-
 		} else
 			return NULL;
 	}	
