@@ -11,14 +11,16 @@ bool isAbove(BranchObj*,BranchObj*);
 
 /*! \brief A branch visible in the map */
 
+/*! If HideExport is used, this branch and its childs will be hidden in export */
+enum HideTmpMode {HideNone, HideExport};
+
+
 /////////////////////////////////////////////////////////////////////////////
 class BranchObj:public OrnamentedObj {
 public:
 	/*! New branches will get use same color for heading as parent */
 	enum BranchModification {NewBranch, MovedBranch};
 
-	/*! If HideExport is used, this branch and its childs will be hidden in export */
-	enum HideTmpMode {HideNone, HideExport};
 
     BranchObj ();
     BranchObj (QGraphicsScene*);
@@ -68,7 +70,7 @@ public:
     virtual void setHeading (QString);
 
 	virtual void setHideTmp (HideTmpMode);
-	virtual bool hasHiddenExportParent (BranchObj*);
+	virtual bool hasHiddenExportParent ();
 
 	virtual QString saveToDir (const QString&,const QString&, const QPointF&);// Save data recursivly to tempdir
 	virtual void addXLink (XLinkObj*);
@@ -112,11 +114,13 @@ public:
     virtual BranchObj* moveBranchUp(BranchObj*);
     virtual bool canMoveBranchDown();
     virtual BranchObj* moveBranchDown(BranchObj*);
+    virtual void sortChildren();
     virtual BranchObj* linkTo (BranchObj*, int);
-    virtual void alignRelativeTo(const QPointF );
+    virtual void alignRelativeTo(const QPointF ref, bool alignSelf=false );
 	virtual void reposition();
 	virtual void unsetAllRepositionRequests();
 
+	virtual QPolygonF shape();				//!< Returns arbitrary bounding polygon
 	virtual QRectF getTotalBBox();			// return BBox including childs			
 	virtual QRectF getBBoxSizeWithChilds();	// return size of BBox including childs  
 	virtual void calcBBoxSizeWithChilds();	// calc size of  BBox including childs recursivly
@@ -124,7 +128,8 @@ public:
     virtual void select();
     virtual void unselect();
 	virtual QString getSelectString();
-	virtual void animate();
+	virtual void setAnimation(const AnimPoint &ap);
+	virtual bool animate();
 
 protected:
 	static BranchObj* itLast;		// iterator for first(), next()
@@ -132,6 +137,9 @@ protected:
     QList<BranchObj*> branch;		// all child branches
 	QList<FloatImageObj*> floatimage;// child images
 	QList<XLinkObj*> xlink;			// xlinks to other branches
+
+	AnimPoint anim;
+
 public:	
 	float angle;					// used in mainbranch to reorder mainbranches
 protected:	
