@@ -53,12 +53,10 @@ void ExportOOFileDialog::init()
 {
 	setMode( QFileDialog::AnyFile );
 	QDir d;
-	d.setPath ("/usr/share/vym/exports");
+	d.setPath (vymBaseDir.path()+"/exports");
 	scanExportConfigs(d);
 	d.setPath (d.homeDirPath()+"/.vym/exports");
 	scanExportConfigs(d);
-	d.setPath (d.currentPath()+"/exports");
-	scanExportConfigs(d);
 
 	connect (
 		this,SIGNAL (filterSelected(const QString&)),
