@@ -4,8 +4,12 @@
 #include <QFileDialog>
 #include <QStringList>
 
+#include "options.h"
 #include "settings.h"
 
+extern Options options;
+extern QDir vymBaseDir;
+
 /*! \brief Dialog to select output file and format for Open Office documents
 
 This is an overloaded QFileDialog, which allows to select templates by setting a type.
