@@ -1,3 +1,4 @@
+#include <QDir>
 #include <QMessageBox>
 #include <QPixmap>
 #include <QLabel>
@@ -7,6 +8,10 @@
 #include "file.h"
 #include "process.h"
 
+#if defined(Q_OS_WIN32)
+#include "mkdtemp.h"
+#include <windows.h>
+#endif
 
 QString maskPath(QString p)
 {
@@ -95,7 +100,7 @@ bool reallyWriteDirectory(const QString &dir)
 		QMessageBox::Warning,
 		QMessageBox::Yes ,
 		QMessageBox::Cancel | QMessageBox::Default,
-		QMessageBox::QMessageBox::NoButton );
+		QMessageBox::NoButton );
 
 		mb.setButtonText( QMessageBox::Yes, QObject::tr("Overwrite") );
 		mb.setButtonText( QMessageBox::No, QObject::tr("Cancel"));
@@ -112,11 +117,29 @@ bool reallyWriteDirectory(const QString &dir)
 	return true;
 }
 
+QString makeTmpDir (bool &ok, QString prefix)
+{
+	bool b;
+	QString path=makeUniqueDir (b,QDir::tempPath()+"/"+prefix+"-XXXXXX");
+	ok=b;
+	return path;
+}
+
+bool isInTmpDir(QString fn)
+{
+	QString temp=QDir::tempPath();
+	int l=temp.length();
+	return fn.left(l)==temp;
+}
+
 QString makeUniqueDir (bool &ok,QString s)
 {
-	// Create unique directory e.g. s="/tmp/vym-XXXXXX"
+	// Create unique directory e.g. for s="/tmp/vym-XXXXXX"
 
-	// Convert QString to string first
+	// Convert Separators
+	s=QDir::convertSeparators(s);
+
+	// Convert QString to string 
 	ok=true;
 	char *p;
 	int bytes=s.length();
@@ -125,6 +148,7 @@ QString makeUniqueDir (bool &ok,QString s)
 	for (i=0;i<bytes;i++)
 		p[i]=s.at(i).latin1();
 	p[bytes]=0;	
+
 	QString r=mkdtemp (p);
 	if (r.isEmpty()) ok=false;
 	free (p);
@@ -133,9 +157,9 @@ QString makeUniqueDir (bool &ok,QString s)
 
 void removeDir(QDir d)
 {
-	if (d.path().left(4)!="/tmp")
+	// This check should_ not be necessary, but proved to be useful ;-)
+	if (!isInTmpDir(d.path()))
 	{
-		// This _should_ not be necessary, but proved to be useful ;-)
 		qWarning ("file.cpp::removeDir should remove "+d.path()+" - aborted.");
 		return;
 	}
@@ -276,6 +300,7 @@ ErrorCode unzipDir (const QDir &zipDir, const QString &zipName)
 	ErrorCode err=success;
 
 	// Try to unzip file
+#if !defined(Q_OS_WIN32)
 	QStringList args;
 	Process *zipProc=new Process ();
 	zipProc->setWorkingDirectory (zipDir.path());
@@ -317,6 +342,45 @@ ErrorCode unzipDir (const QDir &zipDir, const QString &zipName)
 			} 
 		}
 	}
+#else
+    // Do this process creation using Win32 API.
+    //! Create process.
+    PROCESS_INFORMATION piProcInfo;
+    STARTUPINFO siStartInfo;
+
+    // Initialize members of the PROCESS_INFORMATION structure.
+    ::ZeroMemory( &piProcInfo, sizeof(PROCESS_INFORMATION) );
+
+    // Set up members of the STARTUPINFO structure.
+    ::ZeroMemory( &siStartInfo, sizeof(STARTUPINFO) );
+    siStartInfo.cb = sizeof(STARTUPINFO);
+
+    // Create command line.
+    QString argv("unzip -o ");
+    argv.append(QDir::convertSeparators(zipName));
+    argv.append(" -d ");
+    argv.append(QDir::convertSeparators(zipDir.path()));
+
+    // Create the child process.
+    if( !::CreateProcess(NULL, 
+        (LPWSTR)argv.unicode(), // command line
+        NULL, // process security attributes
+        NULL, // primary thread security attributes
+        TRUE, // handles are inherited
+        0, // creation flags
+        NULL, // use parent's environment
+        NULL, // use parent's current directory
+        &siStartInfo, // STARTUPINFO pointer
+        &piProcInfo) ) // receives PROCESS_INFORMATION
+    {
+        err = aborted;
+    }
+    else
+    {
+        // Wait for it to finish.
+        ::WaitForSingleObject( piProcInfo.hProcess, 10000 );
+    }
+#endif
 	return err;	
 }
 
