@@ -16,7 +16,9 @@ QString convertToRel (const QString &,const QString &);
 QString browseDirectory (QWidget *parent=NULL, const QString &caption="");
 bool reallyWriteDirectory(const QString &dir);
 
-QString makeUniqueDir (bool &,QString);
+QString makeTmpDir (bool &ok, QString prefix);
+bool isInTmpDir (QString fn);
+QString makeUniqueDir (bool &ok, QString);
 void removeDir(QDir);
 void copyDir (QDir src,QDir dst);
 void makeSubDirs (const QString &);
