@@ -1,12 +1,12 @@
 #ifndef FINDWINDOW_H 
 #define FINDWINDOW_H
 
-#include <qmainwindow.h>
-#include <qcombobox.h>
-#include <qpushbutton.h>
-#include <qgroupbox.h>
-#include <qlayout.h>
-#include <qlabel.h>
+#include <QMainWindow>
+#include <QComboBox>
+#include <QPushButton>
+#include <QGroupBox>
+#include <QLayout>
+#include <QLabel>
 
 
 class FindWindow : public QGroupBox
@@ -14,13 +14,14 @@ class FindWindow : public QGroupBox
 	Q_OBJECT
 
 public:
-	FindWindow (QWidget* parent=0, const char* namme=0);
+	FindWindow (QWidget* parent=0);
 
 public slots:	
 	void popup();
 	void cancelPressed();
 	void findPressed();
 	void findTextChanged(const QString&);
+	void clearLineEdit();
 
 signals:
 	void findButton(QString);		// emit to mainwindow
