@@ -185,15 +185,15 @@ QString FloatImageObj::saveToDir (const QString &tmpdir,const QString &prefix)
 	QString zAttr=attribut ("zPlane",QString().setNum(zPlane));
 	QString url;
 
-	url="images/"+prefix+"image-" + QString().number(saveCounter,10) + "." +filetype;
+	url="images/"+prefix+"image-" + QString().number(saveCounter,10) + ".png" ;
 
 	// And really save the image
-	icon->save (tmpdir + "/" + url, "PNG");
+	icon->save (tmpdir +"/"+ url, "PNG");
  
 	QString nameAttr=attribut ("orgName",originalFilename);
 
     return singleElement ("floatimage",  
-		getOrnAttr() 
+		getOrnXMLAttr() 
 		+useOrientAttr 
 		+saveInMapAttr 
 		+exportAttr  
@@ -225,7 +225,8 @@ void FloatImageObj::calcBBoxSizeWithChilds()
 	//TODO abstract in linkablemapobj.h
 }
 
-QString FloatImageObj::getSelectString()
+/*
+QString FloatImageObj::getSelectString()  //FIXME move to selection
 {
 	QString s;
 	if (parObj)
@@ -240,4 +241,5 @@ QString FloatImageObj::getSelectString()
 	return s;
 
 }
+*/
 
