@@ -3,10 +3,12 @@
 
 #include "mapobj.h"
 
+/*! \brief The heading of an OrnamentedObj */
+
 class HeadingObj:public MapObj {
 public:
     HeadingObj();
-    HeadingObj(QCanvas*);
+    HeadingObj(QGraphicsScene*);
     virtual ~HeadingObj();
     virtual void init();
     virtual void copy(HeadingObj*);
@@ -15,7 +17,8 @@ public:
     virtual void positionBBox();
 	virtual void calcBBoxSize();
 private:
-    QCanvasText* newLine(QString);				// generate new textline
+//    QGraphicsSimpleTextItem* newLine(QString);		// generate new textline
+    QGraphicsTextItem* newLine(QString);		// generate new textline
 public:    
     virtual void setText(QString);
     virtual QString text();
@@ -24,13 +27,14 @@ public:
     virtual void setColor(QColor);
     virtual QColor getColor();
     virtual void setVisibility(bool);
-	virtual int getHeight();
-	virtual int getWidth();
+	virtual qreal getHeight();
+	virtual qreal getWidth();
 
 protected:
     QString heading;
-    uint textwidth;								// width for formatting text
-    QPtrList <QCanvasText> textline;			// a part of e.g. the parabel
+    int textwidth;								// width for formatting text
+//    QList <QGraphicsSimpleTextItem*> textline;	// a part of e.g. the parabel
+    QList <QGraphicsTextItem*> textline;	// a part of e.g. the parabel
     QColor color;
     QFont font;
 };
