@@ -180,7 +180,7 @@ qreal LinkableMapObj::getRightPad()
 
 LinkableMapObj::Style LinkableMapObj::getDefLinkStyle ()
 {
-	if (mapEditor==0) return UndefinedStyle;
+	if (!mapEditor) return UndefinedStyle;
 	Style ls=mapEditor->getMapLinkStyle();
 	switch (ls)
 	{
@@ -560,10 +560,10 @@ LinkableMapObj* LinkableMapObj::findObjBySelect (QString s)
 				break;
 		} else
 			if (typ=="bo:")
-				lmo=((BranchObj*)(lmo))->getBranchNum (num.toInt());
+				lmo=((BranchObj*)lmo)->getBranchNum (num.toInt());
 			else
 				if (typ=="fi:")
-					lmo=((BranchObj*)(lmo))->getFloatImageNum (num.toUInt());
+					lmo=((BranchObj*)lmo)->getFloatImageNum (num.toUInt());
 		if (!lmo) break;
 		
 		if (s.contains(","))
