@@ -6,9 +6,11 @@
 #include "headingobj.h"
 #include "flagrowobj.h"
 
-
 #define MAX_DEPTH 999
 
+class MapEditor;
+
+
 
 /*! \brief This class adds links to MapObj 
 
@@ -100,21 +102,16 @@ public:
 	virtual MapEditor* getMapEditor();		// get MapEditor (usually from parent);
 	virtual QPointF getRandPos();			// make randomised position
 
-    //virtual void alignRelativeTo(const QPointF );
 	virtual void reposition();
 	virtual void requestReposition();		// do reposition after next user event
 	virtual void forceReposition();			// to force a reposition now (outside
 											// of mapeditor e.g. in noteeditor
 	virtual bool repositionRequested();
 
-	//virtual QRectF getTotalBBox();			// return BBox including childs			
-	//virtual QRectF getBBoxSizeWithChilds();// return size of BBox including childs  
 	virtual void calcBBoxSizeWithChilds()=0;// calc size of  BBox including childs recursivly
 
     virtual void select();
     virtual void unselect();
-	virtual	QString getSelectString()=0;
-	//virtual QString saveToDir (const QString&,const QString&, const QPointF&);// Save data to XML
 
 protected:
 	void parabel(QPolygonF &,double,double,double,double);	// Create Parabel connecting two points
