@@ -1,12 +1,8 @@
+#include "mkdtemp.h"
 #include <stdint.h>
 #include <string.h>
 #include <errno.h>
 #include <io.h>
-#include <sys/time.h>
-
-extern "C" {
-pid_t getpid (void);
-}
 
 char *
 mkdtemp(char *tmpl)
