@@ -5,12 +5,12 @@
 
 class NoteObj;
 
-#include "misc.h"
+#include "xmlobj.h"
 
 /*! \brief The text note belonging to one OrnamentedObj */
 
 
-class NoteObj:public xmlObj
+class NoteObj:public XMLObj
 {
 public:
 	NoteObj();
@@ -20,6 +20,7 @@ public:
 	void setNote (const QString&);
 	QString getNote();
 	QString getNoteASCII();
+	QString getNoteASCII(const QString &indent, const int &width);
 	QString getNoteOpenDoc();
 	void setFontHint (const QString&);
 	QString getFontHint ();
