@@ -1,27 +1,32 @@
 #ifndef OPTIONS_H
 #define OPTIONS_H
 
-#include <qstring.h>
-#include <qstringlist.h>
-
-enum OptionType  {SwitchOption,StringOption};
+#include <QStringList>
 
+/*! \brief A single option which is listed in Options */
 class Option
 {
 public:
+	/*! Types of options */
+	enum Type  {
+		Switch,	//!< No paramater
+		String	//!< Parameter is a string
+	};
+
 	Option();
-	void set (const QString &, const OptionType &, const QString &, const QString &);
+	Option(const QString &, const Type &, const QString &, const QString &);
+	void set (const QString &, const Type &, const QString &, const QString &);
 	QString getName();
 	QString getShort();
 	QString getLong();
-	OptionType getType();
+	Type getType();
 	void setArg(const QString &);
 	QString getArg();
 	void setActive();
 	bool isActive();
 private:
 	QString name;
-	OptionType type;
+	Type type;
 	QString sName;
 	QString lName;
 	QString sarg;
@@ -29,15 +34,15 @@ private:
 };
 
 
-
-typedef QValueList <Option> OptionList;
+/*! \brief Simple class to deal with command line options */
 
 class Options
 {
 public:
 	Options();
 	int parse();
-	void add (const QString &,const OptionType &, const QString &, const QString&);
+	void add (Option );
+	void add (const QString &,const Option::Type &, const QString &, const QString&);
 	void setHelpText(const QString&);
 	QString getHelpText();
 	QString getProgramName();
@@ -49,7 +54,7 @@ private:
 	QString progname;
 	QString helptext;
 	QStringList filelist;
-    OptionList optlist;
+    QList <Option> optlist;
 };
 
 #endif
