@@ -1,3 +1,5 @@
+#include <typeinfo> 
+
 #include "ornamentedobj.h"
 #include "texteditor.h"
 #include "mapeditor.h"
@@ -55,6 +57,8 @@ void OrnamentedObj::init ()
 	standardFlags->clone(standardFlagsDefault);
 	standardFlags->setName ("standardFlags");
 
+	attributes.clear();
+
 	frame = new FrameObj (scene);
 
 	hideExport=false;
@@ -243,7 +247,7 @@ void OrnamentedObj::moveBy (QPointF p)
 
 void OrnamentedObj::move2RelPos(double x, double y)
 {
-	setRelPos (QPointF((int)x,(int)y));
+	setRelPos (QPointF(x,y));
 	if (parObj)
 	{
 		QPointF p=parObj->getChildPos();
@@ -273,6 +277,11 @@ QString OrnamentedObj::getNote()
     return note.getNote();
 }
 
+QString OrnamentedObj::getNoteASCII(const QString &indent, const int &width)
+{
+    return note.getNoteASCII(indent,width);
+}
+
 QString OrnamentedObj::getNoteASCII()
 {
     return note.getNoteASCII();
@@ -336,6 +345,16 @@ QString OrnamentedObj::getVymLink()
 }
 
 
+void OrnamentedObj::setAttributes (const QList <Attribute> &al)
+{
+	attributes=al;
+}
+
+QList <Attribute> OrnamentedObj::getAttributes()
+{
+	return attributes;
+}
+
 void OrnamentedObj::clearStandardFlags()
 {
 	standardFlags->deactivateAll();
@@ -452,7 +471,7 @@ bool OrnamentedObj::isHidden()
 	return hidden;
 }	
 
-QString OrnamentedObj::getOrnAttr()
+QString OrnamentedObj::getOrnXMLAttr()
 {
 	QString posAttr;
 
@@ -463,10 +482,13 @@ QString OrnamentedObj::getOrnAttr()
 	else
 	{
 		if (depth==1 || typeid (*this)==typeid (FloatImageObj))
+		{
+			if (relPos.x()==0 && relPos.y()==0)
+				setRelPos();
 			posAttr=
 				attribut("relPosX",QString().setNum(relPos.x())) +
 				attribut("relPosY",QString().setNum(relPos.y())); 
-		else
+		} else
 			posAttr="";
 	}	
 
