@@ -40,16 +40,17 @@ void Selection::clear()
 void Selection::update()
 {
 	QRectF bbox;
-	int w=0;
 	for (int i=0; i< selectList.count(); ++i) 
 	{
 		bbox=selectList.at(i)->getBBox();
 		selboxList.at(i)->setRect (
-			bbox.x()-w,bbox.y()-w, 
-			bbox.width()+2*w, bbox.height()+2*w);
+			bbox.x(),bbox.y(), 
+			bbox.width(), bbox.height());
 		selboxList.at(i)->setPen (color);	
 		selboxList.at(i)->setBrush (color);	
+		selboxList.at(i)->show();
 	}	
+	model->getMapEditor()->getScene()->update();
 }
 
 void Selection::setColor (QColor col)
@@ -82,6 +83,12 @@ bool Selection::select(LinkableMapObj *lmo)	// TODO no multiselections yet
 
 bool Selection::select (const QString &s)	// TODO no multiselections yet
 {
+	if (s.isEmpty())
+	{
+		unselect();
+		return true;
+	}
+
 	LinkableMapObj *lmo=model->findObjBySelect(s);
 
 	// Finally select the found object
