@@ -6,13 +6,11 @@
 #include <QGraphicsScene>
 
 
-class MapEditor;
 class BranchObj;
 class FloatImageObj;
 class MapCenterObj;
 class LinkableMapObj;
-
-
+class VymModel;
 
 
 class Selection 
@@ -23,7 +21,7 @@ public:
 	~Selection();
 	void copy(const Selection&);
 	void clear();
-	void setMapEditor (MapEditor *);
+	void setModel (VymModel *);
 	void update();
 	void setColor (QColor c);
 	QColor getColor ();
@@ -46,8 +44,7 @@ private:
 	QList <LinkableMapObj*> selectList;
 	QList <LinkableMapObj*> lastSelectList;
 	QList <QGraphicsRectItem*> selboxList;
-	MapEditor *mapEditor;
-	MapCenterObj *mapCenter;
+	VymModel *model;
 	QGraphicsScene *scene;
 
 	QColor color;
