@@ -5,7 +5,7 @@
 #include <qstring.h>
 #include <qstringlist.h>
 
-#include "misc.h"
+#include "xmlobj.h"
 
 // Some helper functions and simplified settings class
 // to read and parse settings e.g.  in undo/redo directories
@@ -29,7 +29,7 @@ private:
 
 // Overloaded QSettings class, used to save some settings in 
 // a map instead of users home directory
-class Settings:public QSettings,public xmlObj
+class Settings:public QSettings,public XMLObj
 {
 public:
     Settings ();
@@ -39,7 +39,7 @@ public:
 	void clearLocal (const QString &);
 	QString readLocalEntry ( const QString &, const QString &, const QString &);
 	void setLocalEntry (const QString &, const QString &, const QString &);
-	QString getXMLData (const QString &);
+	QString getDataXML (const QString &);
 
 protected:
 	QStringList pathlist;
