@@ -72,7 +72,7 @@ bool parseBaseHandler::fatalError( const QXmlParseException& exception )
 		QStringList sl=QStringList::split ("\n",s);
 		int i=1;
 		QStringList::Iterator it = sl.begin();
-		while (i<exception.lineNumber()-1)
+		while (i<exception.lineNumber())
 		{
 			it++;
 			i++;
