@@ -60,7 +60,7 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
 		<<">  state="<<state 
 		<<"  laststate="<<stateStack.last()
 		<<"   loadMode="<<loadMode
-		<<"       line="<<QXmlDefaultHandler::lineNumber()
+		//<<"       line="<<QXmlDefaultHandler::lineNumber()
 		<<endl;
 	*/	
 	stateStack.append (state);	
@@ -150,18 +150,23 @@ bool parseVYMHandler::startElement  ( const QString&, const QString&,
 			// Treat the found mapcenter as a branch 
 			// in an existing map
 			LinkableMapObj* lmo=model->getSelection();
-			if (lmo && ((typeid(*lmo) == typeid(BranchObj) ) 
-			        ||  typeid(*lmo) == typeid(MapCenterObj) ) )
+			if (lmo)
 			{
-				lastBranch=(BranchObj*)lmo;
-				if (loadMode==ImportAdd)
+				if ( (typeid(*lmo) == typeid(BranchObj) ) 
+						||  typeid(*lmo) == typeid(MapCenterObj) ) 
 				{
-					lastBranch->addBranch();
-					lastBranch=lastBranch->getLastBranch();
-				} else
-					lastBranch->clear();
+					lastBranch=(BranchObj*)lmo;
+					if (loadMode==ImportAdd)
+					{
+						lastBranch->addBranch();
+						lastBranch=lastBranch->getLastBranch();
+					} else
+						lastBranch->clear();
+				}	
 			} else
-				return false;
+				// Add mapCenter without parent
+				lastBranch=model->addMapCenter();
+			
 		}
 		readBranchAttr (atts);
 	} else if ( 
@@ -286,6 +291,10 @@ bool parseVYMHandler::endElement  ( const QString&, const QString&, const QStrin
     switch ( state ) 
 	{
         case StateBranch: 
+			// Empty branches may not be scrolled 
+			// (happens if bookmarks are imported)
+			if (lastBranch->isScrolled() && lastBranch->countBranches()==0) 
+				lastBranch->unScroll();
 			lastBranch=(BranchObj*)(lastBranch->getParObj());
             break;
         case StateHtml: 
@@ -422,7 +431,7 @@ bool parseVYMHandler::readOOAttr (const QXmlAttributes& a)
 					return false;   // Couldn't read relPos
 			}           
 		}           
-		if (!a.value( "absPosX").isEmpty() && loadMode==NewMap ) 
+		if (!a.value( "absPosX").isEmpty() ) 
 		{
 			if (!a.value( "absPosY").isEmpty() ) 
 			{
